%global readers_dir %(pkg-config libpcsclite --variable=usbdropdir)
%global withGUI 0

%define		main_version 3.99.5
%define		sub_version SP08

Name:		pcsc-cyberjack
Version:	%main_version.%sub_version
Release:	%mkrel 2
Summary:	PC/SC driver for REINER SCT cyberjack USB chipcard reader
License:	LGPLv2+
Group:		System/Kernel and hardware
URL:		http://www.reiner-sct.com/
Source0:	http://support.reiner-sct.de/downloads/LINUX/V%{main_version}_%{sub_version}/%{name}-%{main_version}final.%{sub_version}.tar.bz2
# (doktor5000) useful hints on troubleshooting / debugging, taken from Fedora
Source1:	http://pkgs.fedoraproject.org/cgit/pcsc-cyberjack.git/plain/%{name}-%{main_version}final.%{sub_version}-README-FEDORA
Patch1:		pcsc-cyberjack-3.99.5final.SP03-glibc-2.17.patch
BuildRequires:	pkgconfig(libpcsclite)
BuildRequires:	pkgconfig(libusb-1.0)
BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:	readline-devel
BuildRequires:	sysfsutils-devel
# for macro definition:
BuildRequires:  systemd-devel
Requires:	pcsc-lite
Requires:	udev

%if %{withGUI}
%package gui
Summary:	Graphical Diagnostic Tool
Requires:	%{name} = %{version}
BuildRequires:	pkgconfig(fox17)
Group:		User Interface/X Hardware Support
%endif

%description
This package includes the IFD driver for the cyberJack contactless (RFID)
and contact USB chipcard reader.

For more information regarding installation under Linux see the README.txt
in the documentation directory, esp. regarding compatibility with host
controllers.

For more information about the reader, software updates and a shop see
http://www.reiner-sct.com/

%if %{withGUI}
%description gui
Graphical diagnostic tool for Reiner SCT cyberJack card readers.

This package contains a graphical tool which lists all connected 
Reiner SCT readers and allows flashing E-Com A and newer readers.

It can also be used to diagnose most frequent problems in the reader-/driver
setup.
%endif


%prep
%setup -q -n %{name}-%{main_version}final.%{sub_version}
%autopatch -p1
autoreconf -ifsv

install -pm 644 %{SOURCE1} README-MAGEIA.txt


%build

%configure2_5x --disable-static \
	--mandir=%{_mandir}/man8 \
	--enable-pcsc \
	--sysconfdir="%{_sysconfdir}" \
	--with-usbdropdir="%{readers_dir}" \
	--enable-release \
	--enable-udev \
	--enable-hal=no \
%if %{withGUI}
	--with-fox-includes=/usr/include/fox-1.7
%else
	--disable-fox
%endif

%make

#manually build extra tools
%make -C tools/cjflash
%make -C tools/cjgeldkarte

%if %{withGUI}
# manually build fox-dialog
pushd tools/fox-dialog
%make
popd
%endif

pushd doc
iconv -f iso8859-1 -t utf-8 LIESMICH.txt > LIESMICH.txt.conv && mv -f LIESMICH.txt.conv LIESMICH.txt
iconv -f iso8859-1 -t utf-8 README.txt > README.txt.conv && mv -f README.txt.conv README.txt
popd

%install
%makeinstall_std

#manually install extra tools
install -m0755 tools/cjflash/cjflash %{buildroot}%{_bindir}
install -m0755 tools/cjgeldkarte/cjgeldkarte %{buildroot}%{_bindir}

%if %{withGUI}
# fox-dialog does not get installes automatically neither
pushd tools/fox-dialog
%makeinstall_std
popd
%else
# fxcyberjack does get installed automatically, but we
# package it into the gui subpackage.
# delete when withGUI 0 to avoid rpm unpackaged file error
rm -rf %{buildroot}/usr/bin/fxcyberjack
%endif

#remove unneeded files
rm -f %{buildroot}%{_libdir}/cyberjack/pcscd_init.diff
rm -f %{buildroot}%{_libdir}/pcsc/drivers/libifd-cyberjack.bundle/Contents/Linux/libifd-cyberjack.la

mv %{buildroot}%{_sysconfdir}/cyberjack.conf.default %{buildroot}%{_sysconfdir}/cyberjack.conf

# udev rule based on the file from debian sub-folder
# we need the devices to be in group cyberjack
sed -i 's/GROUP="pcscd"/GROUP="cyberjack"/' debian/libifd-cyberjack6.udev
install -Dm 644 debian/libifd-cyberjack6.udev %{buildroot}%{_udevrulesdir}/93-cyberjack.rules


%pre
%_pre_groupadd cyberjack

%post
%udev_rules_update

%systemd_postun_with_restart pcscd.socket


%postun
%udev_rules_update

%systemd_postun_with_restart pcscd.socket


%files
# AUTHORS is 0 length and will not be packaged therefore
%doc etc/cyberjack.conf.default README-MAGEIA.txt ChangeLog
%doc doc/README.txt doc/README.pdf doc/README.html
%doc doc/LIESMICH.txt doc/LIESMICH.pdf doc/LIESMICH.html
%doc COPYING COPYRIGHT.GPL COPYRIGHT.LGPL

%config(noreplace) %{_sysconfdir}/cyberjack.conf
%{_bindir}/cyberjack
%{_bindir}/cjflash
%{_bindir}/cjgeldkarte
# getdist.sh is used by the binary cyberjack
%{_libdir}/cyberjack/getdist.sh
%{_udevrulesdir}/93-cyberjack.rules
%{readers_dir}/libifd-cyberjack.bundle/Contents/Info.plist
%{readers_dir}/libifd-cyberjack.bundle/Contents/PkgInfo
%{readers_dir}/libifd-cyberjack.bundle/Contents/Linux/libifd-cyberjack.so
%{readers_dir}/libifd-cyberjack.bundle/Contents/Linux/libifd-cyberjack.so.*
%{_mandir}/man8/cyberjack.8*
%if %{withGUI}
%files gui
%doc COPYING COPYRIGHT.GPL COPYRIGHT.LGPL
# cyberjack-gui starts but no display fxcyberjack works fine
%{_bindir}/cyberjack-gui
%{_bindir}/fxcyberjack
%endif


%changelog
* Sun Oct 16 2016 tv <tv> 3.99.5.SP08-2.mga6
+ Revision: 1061155
- BR systemd-devel for macro definition (mga#12027)

* Fri Jan 01 2016 doktor5000 <doktor5000> 3.99.5.SP08-1.mga6
+ Revision: 917662
- use %%configure2_5x instead of %%configure to fix build
- new version 3.99.5-SP08
- synced with Fedora
  o added helpful README from Fedora as README-MAGEIA.txt
  o use pkg-config to find correct target directory for pcsc drivers
  o install config as %%{_sysconfdir}/cyberjack.conf and not as .default
  o mark %%{_sysconfdir}/cyberjack.conf as %%config(noreplace)
- devices created by udev have to be in group "cyberjack", not in "pcscd"
  o create group cyberjack in %%post with rpm-helper if not existent
  o update udev rules database in %%post / %%postun
- restart pcsc.socket during uninstallation
- added -gui subpackage and conditional for it, disabled for now

* Wed Oct 15 2014 umeabot <umeabot> 3.99.5.SP03-6.mga5
+ Revision: 739335
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 3.99.5.SP03-5.mga5
+ Revision: 727545
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 3.99.5.SP03-4.mga5
+ Revision: 683373
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 3.99.5.SP03-3.mga4
+ Revision: 509250
- Mageia 4 Mass Rebuild

* Sun Jan 13 2013 cjw <cjw> 3.99.5.SP03-2.mga3
+ Revision: 363236
- patch1: fix build with glibc 2.17

  + umeabot <umeabot>
    - Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jan 23 2012 doktor5000 <doktor5000> 3.99.5.SP03-1.mga2
+ Revision: 200261
- fix license tag to LGPLv2+
- add %%sub_version to %%version
- use placeholders in %%files list
- imported package pcsc-cyberjack

